@@ -42,7 +42,7 @@ double colresmduneg( const size_t n, const size_t m, double** delta, const size_
   for ( size_t i = 1; i <= n; i++ ) for ( size_t k = 1; k <= p; k++ ) nfx += fx[i][k];
 
   // update distances and calculate normalized stress
-  gemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
+  dgemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
   euclidean2( n, p, x, m, y, d );
   double fold = 0.0;
   for ( size_t i = 1; i <= n; i++ ) {
@@ -122,8 +122,8 @@ double colresmduneg( const size_t n, const size_t m, double** delta, const size_
       }
     }
     inverse( h, hhh );
-    gemm( true, true, h, n, m, 1.0, q, imw, 0.0, hhn );
-    gemm( false, false, h, p, n, 1.0, hhn, x, 0.0, hhp );
+    dgemm( true, true, h, n, m, 1.0, q, imw, 0.0, hhn );
+    dgemm( false, false, h, p, n, 1.0, hhn, x, 0.0, hhp );
     for ( size_t i = 1; i <= h; i++ ) {
       for ( size_t j = 1; j <= p; j++ ) {
         double work = 0.0;
@@ -131,10 +131,10 @@ double colresmduneg( const size_t n, const size_t m, double** delta, const size_
         hhp[i][j] += work;
       }
     }
-    gemm( false, false, h, p, h, 1.0, hhh, hhp, 0.0, b );
+    dgemm( false, false, h, p, h, 1.0, hhh, hhp, 0.0, b );
 
     // update y
-    gemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
+    dgemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
 
     // update distances and calculate normalized stress
     euclidean2( n, p, x, m, y, d );
