@@ -4,15 +4,14 @@
 // This is a permissive non-copyleft free software license that is compatible with the GNU GPL.
 //
 
-#include "flib.h"
 #include "fmdu.h"
 
 double colreswgtmduneg( const size_t n, const size_t m, double** delta, double** w, const size_t p, double** x, int** fx, const size_t h, double** q, double** b, double** d, const size_t MAXITER, const double FCRIT, size_t* lastiter, double* lastdif, const bool echo )
 // Function colresmduneg() performs column restricted multidimensional unfolding allowing negative dissimilarities.
 {
-  const double EPS = DBL_EPSILON;                                          // 2.2204460492503131e-16
-  const double TOL = sqrt( EPS );                                          // 1.4901161193847656e-08
-  const double CRIT = sqrt( TOL );                                         // 0.00012207031250000000
+  const double EPS = DBL_EPSILON;                                              // 2.2204460492503131e-16
+  const double TOL = sqrt( EPS );                                              // 1.4901161193847656e-08
+  const double CRIT = sqrt( TOL );                                             // 0.00012207031250000000
   const double TINY = pow( 10.0, ( log10( EPS ) + log10( TOL ) ) / 2.0 );  // 1.8189894035458617e-12
   const double DISCRIT = TINY;
   const double EPSCRIT = 0.25 * TINY;
@@ -41,7 +40,7 @@ double colreswgtmduneg( const size_t n, const size_t m, double** delta, double**
   for ( size_t i = 1; i <= n; i++ ) for ( size_t k = 1; k <= p; k++ ) nfx += fx[i][k];
 
   // update distances and calculate normalized stress
-  gemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
+  dgemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
   euclidean2( n, p, x, m, y, d );
   double fold = 0.0;
   for ( size_t i = 1; i <= n; i++ ) {
@@ -101,7 +100,7 @@ double colreswgtmduneg( const size_t n, const size_t m, double** delta, double**
     }
 
     // update x
-    gemm( false, false, m, p, n, 1.0, w, y, 0.0, hnp );
+    dgemm( false, false, m, p, n, 1.0, w, y, 0.0, hnp );
     for ( size_t i = 1; i <= n; i++ ) {
       double rsw = 0.0;
       for ( size_t j = 1; j <= m; j++ ) rsw += imw[i][j];
@@ -117,8 +116,8 @@ double colreswgtmduneg( const size_t n, const size_t m, double** delta, double**
       }
     }
     inverse( h, hhh );
-    gemm( true, true, h, n, m, 1.0, q, imw, 0.0, hhn );
-    gemm( false, false, h, p, n, 1.0, hhn, x, 0.0, hhp );
+    dgemm( true, true, h, n, m, 1.0, q, imw, 0.0, hhn );
+    dgemm( false, false, h, p, n, 1.0, hhn, x, 0.0, hhp );
     for ( size_t i = 1; i <= h; i++ ) {
       for ( size_t j = 1; j <= p; j++ ) {
         double work = 0.0;
@@ -126,10 +125,10 @@ double colreswgtmduneg( const size_t n, const size_t m, double** delta, double**
         hhp[i][j] += work;
       }
     }
-    gemm( false, false, h, p, h, 1.0, hhh, hhp, 0.0, b );
+    dgemm( false, false, h, p, h, 1.0, hhh, hhp, 0.0, b );
 
     // update y
-    gemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
+    dgemm( false, false, m, p, h, 1.0, q, b, 0.0, y );
 
     // update distances and calculate normalized stress
     euclidean2( n, p, x, m, y, d );
